/*

  Author(s): Ilja V. Ryndin (ryndin@pinebrush.com)

  Start date: *

*/

#ifndef FILEAUDITWIDGET_H
#define FILEAUDITWIDGET_H

#include "parsec_aud_qt5_global.h"

#include <sys/stat.h>

#include <QWidget>

class QCheckBox;
class QPushButton;

namespace ParsecQt5
{
    class FileAuditHeadWidget;
    class FileAuditScrollArea;
    class PARSEC_AUD_QT5_EXPORT FileAuditWidget : public QWidget {
    Q_OBJECT
    public:
        FileAuditWidget( QWidget *parent = 0 );
        virtual ~FileAuditWidget();
        void getfaud( const QString &path );
        bool chaud( const QString &path );
    signals:
        void changed();
    private slots:
        void emitChanged();

        void addAuditElement();
        void checkRemoveCondition();
        void showRegularAudit();
        void hideRegularAudit();
        void showDefaultAudit();
        void hideDefaultAudit();
        void switchToDefaultAudit();
        void switchToRegularAudit();
        void setRegularVisible( bool );
        void setDefaultVisible( bool );
        void disableDefault();
        void reselect( int = 0 );
    private:
        void checkMode();

        void rebuildContents( const QString & );
        void rebuildAuditList( const QString & );
        void updateContents();
        bool defaultAvailable();

        bool m_regularIsVisible;
        bool m_defaultIsVisible;
        bool m_defaultIsDisabled;
        bool m_isSwitchMode;

        QCheckBox *m_userSelectCheckBox;
        QCheckBox *m_groupSelectCheckBox;
        QCheckBox *m_otherSelectCheckBox;

        FileAuditHeadWidget *m_auditHeadWidget;
        FileAuditScrollArea *m_auditScrollArea;
        QPushButton *m_showRegularAuditButton;
        QPushButton *m_hideRegularAuditButton;
        QPushButton *m_showDefaultAuditButton;
        QPushButton *m_hideDefaultAuditButton;
        QPushButton *m_switchToDefaultAuditButton;
        QPushButton *m_switchToRegularAuditButton;
        QPushButton *m_addAuditElementButton;

        QString m_user;
        QString m_group;

        struct stat m_stat;
        bool m_isSuccessedStat;
    };
}

#endif // FILEAUDITWIDGET_H
